from collinear.judge.collinear_guard import CollinearGuard
from collinear.judge.veritas import Veritas


class Judge:
    def __init__(self, access_token: str) -> None:
        self.access_token = access_token
        self._veritas = None
        self._collinear_guard = None

    @property
    def veritas(self):
        """
        Lazy-load Veritas service when accessed for the first time.
        Cache the result for subsequent accesses.
        """
        if self._veritas is None:
            self._veritas = Veritas(self.access_token)
        return self._veritas

    @property
    def collinear_guard(self):
        """
        Lazy-load Collinear Guard service when accessed for the first time.
        Cache the result for subsequent accesses.
        """
        if self._collinear_guard is None:
            self._collinear_guard = CollinearGuard(self.access_token)
        return self._collinear_guard



from setuptools import setup, find_packages


setup(
    name = 'collinear',
    version = "0.1.0",
    author = 'Collinear AI',
    author_email = 'info@collinear.ai',
    url = 'https://www.collinear.ai/',
    description = 'Collinear AI Python Client.',
    long_description_content_type = "text/x-rst",  # If this causes a warning, upgrade your setuptools package
    license = "MIT license",
    packages = find_packages(exclude=["test"]),  # Don't include test directory in binary distribution
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]  # Update these accordingly
)



from typing import Literal, overload
from collinear.judge import Judge


class Collinear:
    def __init__(self, access_token: str) -> None:
        self.access_token = access_token
        self._judge = None

    @property
    def judge(self):
        """
        Lazy-load Veritas service when accessed for the first time.
        Cache the result for subsequent accesses.
        """
        if self._judge is None:
            self._judge = Judge(self.access_token)
        return self._judge
